package com.gx.obe.step.appraise.enumeration;

import java.util.Arrays;
import java.util.List;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import com.gx.obe.step.appraise.bean.Appraise;
import com.gx.obe.util.utils.PredicateUtils;

/** 
 * @Description: 专家评价枚举
 * @author chenxw 
 */
public enum AppraiseExpertEnum {
	
	/**
	 * 守时情况
	 */
	PUNCTUAL_SITUATION("01", "守时情况", 20, AppraiserEnum.MANAGER, 
			"1.按时参加且无早退现象，满分；\r\n" + 
			"2.未在指定时间到达集合地点，迟到不超过一个小时的，扣5分；\r\n" + 
			"3.未在指定时间到达集合地点，迟到超过一个小时但不超过两个小时的，扣10分；\r\n" + 
			"4.迟到两个小时以上，不得分；\r\n" + 
			"5.未经评标组长同意，提前早退的，不得分。"),
	/**
	 * 评标公正性
	 */
	EVALUATION_FAIRNESS("02", "评标公正性", 20, AppraiserEnum.EXPERT, 
			"1.评标公正，满分；\r\n" + 
			"2.主观评审，评分为0分或满分，且做出的解释说明不合理的，扣10分；\r\n" + 
			"3.不按照招标文件载明的评标办法进行评分，此项得0分。"),
	/**
	 * 评标纪律遵守情况
	 */
	EVALUATION_DISCIPLINE("03", "评标纪律遵守情况", 20, AppraiserEnum.MANAGER, 
			"1.自觉遵守维护评标过程纪律，满分；\r\n" + 
			"2.评标工作未结束，提出要先行离开，经说服后继续评审，扣5分；\r\n" + 
			"3.故意拖延评标时间，影响评标工作进度，扣5分；\r\n" + 
			"4.将通讯工具带入评标区的，扣5分；\r\n" + 
			"5.在评标过程中擅离职守，但未影响评标程序正常进行的，扣10分；\r\n" + 
			"6．评标工作未结束，提出要先行离开，不听劝说。此项得0分；\r\n" + 
			"7.干扰、影响其他评委独立打分，扣10分；\r\n" + 
			"8.与其他评委商量打分，此项得0分；\r\n" + 
			"9.不服从评标现场管理的其他行为，此项得0分；\r\n" + 
			"10.拒绝在评标结果上签字且不以书面形式详细说明原因的，此项得0分；\r\n" + 
			"11.将投标文件及与评标内容有关的资料以记录、摘抄、复印、拍照等任何形式带离评或泄漏出评标现场的，此项得0分；\r\n" + 
			"12.不配合监督部门依职权进行的调查的，此项得0分。"),
	/**
	 * 专业能力
	 */
	PROFESSIONAL_ABILITY("04", "专业能力", 20, AppraiserEnum.EXPERT, 
			"1.精通所评专业，满分；\r\n" + 
			"2.评标报告或评标资料中非关键性内容表述错误的，扣5分；\r\n" + 
			"3.评标报告或评标资料中关键性内容表述错误的，扣20分；\r\n" + 
			"4.对所评专业只有基本常识的了解，评标业务能力较差，扣10分；\r\n" + 
			"5.无法胜任所评专业，此项得0分；\r\n" + 
			"6.未经认真评标研读招标文件和投标文件，直接在评分表上打分，扣10分。"),
	/**
	 * 职业操守
	 */
	OCCUPATION_ETHICS("05", "职业操守", 20, AppraiserEnum.MANAGER, 
			"1.有基本的职业操守，满分；\r\n" + 
			"2.评标期间谈论与评标内容无关事项影响项目正常评审的，扣5分；\r\n" + 
			"3.个人职称、履历等信息不完整或发生变化，未及时补充或者修改完善影响评标专家抽取和评标工作的，扣5分；\r\n" + 
			"4.对评审劳务报酬提出不合理要求，扣10分；\r\n" + 
			"5.评标过程中，工作态度消极，影响评标工作进度的扣10分；\r\n" + 
			"6.故意拖延时间增加报酬，此项得0分；\r\n" + 
			"7.未依法履行保密义务，向他人透露对投标文件的评审和比较、中标候选人的推荐等与评标有关的其他情况的，此项得0分。");
	
	private Appraise appraise;
	private AppraiserEnum appraiser;
	
	private AppraiseExpertEnum(String key, String name, int score, AppraiserEnum appraiser, String rule) {
		this.appraiser = appraiser;
		this.appraise = new Appraise(key, name, score, rule, appraiser.getKey());
	}
	
	public Appraise getAppraise() {
		return appraise;
	}
	
	public AppraiserEnum getAppraiser() {
		return appraiser;
	}
	
	/**
	 * @Description: 根据评价人获取枚举列表
	 * @author chenxw
	 * @param appraiser
	 * @return 
	 */
	public static List<AppraiseExpertEnum> getListByAppraiser(AppraiserEnum appraiser) {
		return Arrays.stream(values())
				.filter(PredicateUtils.apply(AppraiseExpertEnum::getAppraiser, Predicate.isEqual(appraiser)))
				.collect(Collectors.toList());
	}
	
}
